((Drupal) => {
  /**
   * Overrides the message theme function using Zurb Foundation markup.
   *
   * @param {object} message
   *   The message object.
   * @param {string} message.text
   *   The message text.
   * @param {object} options
   *   The message context.
   * @param {string} options.type
   *   The message type (e.g., 'status', 'error', 'warning').
   * @param {string} options.id
   *   ID of the message.
   *
   * @return {HTMLElement}
   *   A DOM Node styled for Zurb Foundation.
   */
  Drupal.theme.message = ({ text }, { type, id }) => {
    const messagesTypes = Drupal.Message.getMessageTypeLabels();
    const wrapper = document.createElement('div');

    // Determine Foundation class for the message type.
    let calloutClass = 'callout';
    if (type === 'error') {
      calloutClass += ' alert';
    } else if (type === 'warning') {
      calloutClass += ' warning';
    } else if (type === 'status') {
      calloutClass += ' success';
    }

    // Set common attributes.
    wrapper.setAttribute('class', calloutClass);
    wrapper.setAttribute('data-closable', '');
    wrapper.setAttribute('role', 'contentinfo');
    wrapper.setAttribute('aria-label', messagesTypes[type]);
    wrapper.setAttribute('data-drupal-message-id', id);
    wrapper.setAttribute('data-drupal-message-type', type);

    // Use a nested <div role="alert"> only for errors.
    const alertWrapperStart = type === 'error' ? '<div role="alert">' : '';
    const alertWrapperEnd = type === 'error' ? '</div>' : '';

    // Message content.
    wrapper.innerHTML = `
      ${alertWrapperStart}
        <h2 class="visually-hidden" id="${id}-title">${messagesTypes[type]}</h2>
        ${text}
      ${alertWrapperEnd}
      <button class="close-button" aria-label="Dismiss alert" type="button" data-close>
        <span aria-hidden="true">&times;</span>
      </button>
    `;

    return wrapper;
  };
})(Drupal);
